@@ -63,8 +63,10 @@ createAlgo <- function(nbBurnInIter = 50, nbIter = 50, nbGibbsBurnInIter = 50, n
 #' @description Compute the discriminative power of each variable or class
 #'
 #'
-#' @param outMixtComp object of class \emph{MixtCompLearn} or \emph{MixtComp} obtained using \code{mixtCompLearn} or \code{mixtCompPredict} functions from \code{RMixtComp} package or \code{rmcMultiRun} from \code{RMixtCompIO} package.
-#' @param class NULL or a number of classes. If NULL, return the discriminative power of variables globally otherwise return the discriminative power of variables in the given class
+#' @param outMixtComp object of class \emph{MixtCompLearn} or \emph{MixtComp} obtained using \code{mixtCompLearn} or
+#' \code{mixtCompPredict} functions from \code{RMixtComp} package or \code{rmcMultiRun} from \code{RMixtCompIO} package.
+#' @param class NULL or a number of classes. If NULL, return the discriminative power of variables globally otherwise
+#' return the discriminative power of variables in the given class
 #'
 #' @return the discriminative power
 #'
@@ -72,7 +74,8 @@ createAlgo <- function(nbBurnInIter = 50, nbIter = 50, nbGibbsBurnInIter = 50, n
 #' The discriminative power of variable j is defined by 1 - C(j)
 #' \deqn{C(j)=  - \sum_{k=1}^K sum_{i=1}^n P(Z_i=k|x_{ij}) \log(P(Z_i=k|x_{ij})) / (n*\log(K))}
 #'
-#' A high value (close to one) means that the variable is highly discriminating. A low value (close to zero) means that the variable is poorly discriminating.
+#' A high value (close to one) means that the variable is highly discriminating. A low value (close to zero) means that
+#' the variable is poorly discriminating.
 #'
 #' The discriminative power of variable j in class k is defined by 1 - C(j)
 #' \deqn{C(j)=  - sum_{i=1}^n (P(Z_i!=k|x_{ij}) \log(P(Z_i!=k|x_{ij})) + P(Z_i=k|x_{ij}) \log(P(Z_i=k|x_{ij}))) / (n*\log(2))}
@@ -83,43 +86,44 @@ createAlgo <- function(nbBurnInIter = 50, nbIter = 50, nbGibbsBurnInIter = 50, n
 #'
 #'
 #' @examples
-#' require(RMixtCompIO) # for learning a mixture model
-#' dataLearn <- list(
-#'   var1 = as.character(c(rnorm(50, -2, 0.8), rnorm(50, 2, 0.8))),
-#'   var2 = as.character(c(rnorm(50, 2), rpois(50, 8)))
-#' )
+#' if (requireNamespace("RMixtCompIO", quietly = TRUE)) {
+#'   dataLearn <- list(
+#'     var1 = as.character(c(rnorm(50, -2, 0.8), rnorm(50, 2, 0.8))),
+#'     var2 = as.character(c(rnorm(50, 2), rpois(50, 8)))
+#'   )
 #'
-#' model <- list(
-#'   var1 = list(type = "Gaussian", paramStr = ""),
-#'   var2 = list(type = "Poisson", paramStr = "")
-#' )
+#'   model <- list(
+#'     var1 = list(type = "Gaussian", paramStr = ""),
+#'     var2 = list(type = "Poisson", paramStr = "")
+#'   )
 #'
-#' algo <- list(
-#'   nClass = 2,
-#'   nInd = 100,
-#'   nbBurnInIter = 100,
-#'   nbIter = 100,
-#'   nbGibbsBurnInIter = 100,
-#'   nbGibbsIter = 100,
-#'   nInitPerClass = 3,
-#'   nSemTry = 20,
-#'   confidenceLevel = 0.95,
-#'   ratioStableCriterion = 0.95,
-#'   nStableCriterion = 10,
-#'   mode = "learn"
-#' )
+#'   algo <- list(
+#'     nClass = 2,
+#'     nInd = 100,
+#'     nbBurnInIter = 100,
+#'     nbIter = 100,
+#'     nbGibbsBurnInIter = 100,
+#'     nbGibbsIter = 100,
+#'     nInitPerClass = 3,
+#'     nSemTry = 20,
+#'     confidenceLevel = 0.95,
+#'     ratioStableCriterion = 0.95,
+#'     nStableCriterion = 10,
+#'     mode = "learn"
+#'   )
 #'
-#' resLearn <- rmcMultiRun(algo, dataLearn, model, nRun = 3)
+#'   resLearn <-RMixtCompIO::rmcMultiRun(algo, dataLearn, model, nRun = 3)
 #'
 #'
-#' discVar <- computeDiscrimPowerVar(resLearn)
-#' discVarInClass1 <- computeDiscrimPowerVar(resLearn, class = 1)
-#' discClass <- computeDiscrimPowerClass(resLearn)
+#'   discVar <- computeDiscrimPowerVar(resLearn)
+#'   discVarInClass1 <- computeDiscrimPowerVar(resLearn, class = 1)
+#'   discClass <- computeDiscrimPowerClass(resLearn)
 #'
-#' # graphic representation of discriminant variables
-#' plotDiscrimVar(resLearn)
-#' # graphic representation of discriminant classes
-#' plotDiscrimClass(resLearn)
+#'   # graphic representation of discriminant variables
+#'   plotDiscrimVar(resLearn)
+#'   # graphic representation of discriminant classes
+#'   plotDiscrimClass(resLearn)
+#' }
 #'
 #' @author Matthieu Marbac
 #' @seealso \code{\link{plotDiscrimClass}} \code{\link{plotDiscrimVar}}
@@ -138,7 +142,8 @@ computeDiscrimPowerVar <- function(outMixtComp, class = NULL) {
 #
 # @description Compute the discriminative power of each variable for a given class
 #
-# @param outMixtComp object of class \emph{MixtCompLearn} or \emph{MixtComp} obtained using \code{mixtCompLearn} or \code{mixtCompPredict} functions from \code{RMixtComp} package or \code{rmcMultiRun} from \code{RMixtCompIO} package.
+# @param outMixtComp object of class \emph{MixtCompLearn} or \emph{MixtComp} obtained using \code{mixtCompLearn} or
+# \code{mixtCompPredict} functions from \code{RMixtComp} package or \code{rmcMultiRun} from \code{RMixtCompIO} package.
 # @param class class for which discriminating power is required
 #
 # The discriminative power of variable j in class k is defined by 1 - C(j)
@@ -175,7 +180,8 @@ computeDiscrimPowerClass <- function(outMixtComp) {
 #' @description Compute the similarity between variables (or classes)
 #'
 #'
-#' @param outMixtComp object of class \emph{MixtCompLearn} or \emph{MixtComp} obtained using \code{mixtCompLearn} or \code{mixtCompPredict} functions from \code{RMixtComp} package or \code{rmcMultiRun} from \code{RMixtCompIO} package.
+#' @param outMixtComp object of class \emph{MixtCompLearn} or \emph{MixtComp} obtained using \code{mixtCompLearn} or
+#' \code{mixtCompPredict} functions from \code{RMixtComp} package or \code{rmcMultiRun} from \code{RMixtCompIO} package.
 #'
 #' @return a similarity matrix
 #'
@@ -187,36 +193,37 @@ computeDiscrimPowerClass <- function(outMixtComp) {
 #' \deqn{Sigma(k,g)^2 = (1/n) * \sum_{i=1}^n (P(Z_i=k|x_i) - P(Z_i=g|x_i))^2}
 #'
 #' @examples
-#' require(RMixtCompIO) # for learning a mixture model
-#' dataLearn <- list(
-#'   var1 = as.character(c(rnorm(50, -2, 0.8), rnorm(50, 2, 0.8))),
-#'   var2 = as.character(c(rnorm(50, 2), rpois(50, 8)))
-#' )
+#' if (requireNamespace("RMixtCompIO", quietly = TRUE)) {
+#'   dataLearn <- list(
+#'     var1 = as.character(c(rnorm(50, -2, 0.8), rnorm(50, 2, 0.8))),
+#'     var2 = as.character(c(rnorm(50, 2), rpois(50, 8)))
+#'   )
 #'
-#' model <- list(
-#'   var1 = list(type = "Gaussian", paramStr = ""),
-#'   var2 = list(type = "Poisson", paramStr = "")
-#' )
+#'   model <- list(
+#'     var1 = list(type = "Gaussian", paramStr = ""),
+#'     var2 = list(type = "Poisson", paramStr = "")
+#'   )
 #'
-#' algo <- list(
-#'   nClass = 2,
-#'   nInd = 100,
-#'   nbBurnInIter = 100,
-#'   nbIter = 100,
-#'   nbGibbsBurnInIter = 100,
-#'   nbGibbsIter = 100,
-#'   nInitPerClass = 3,
-#'   nSemTry = 20,
-#'   confidenceLevel = 0.95,
-#'   ratioStableCriterion = 0.95,
-#'   nStableCriterion = 10,
-#'   mode = "learn"
-#' )
+#'   algo <- list(
+#'     nClass = 2,
+#'     nInd = 100,
+#'     nbBurnInIter = 100,
+#'     nbIter = 100,
+#'     nbGibbsBurnInIter = 100,
+#'     nbGibbsIter = 100,
+#'     nInitPerClass = 3,
+#'     nSemTry = 20,
+#'     confidenceLevel = 0.95,
+#'     ratioStableCriterion = 0.95,
+#'     nStableCriterion = 10,
+#'     mode = "learn"
+#'   )
 #'
-#' resLearn <- rmcMultiRun(algo, dataLearn, model, nRun = 3)
+#'   resLearn <-RMixtCompIO::rmcMultiRun(algo, dataLearn, model, nRun = 3)
 #'
-#' simVar <- computeSimilarityVar(resLearn)
-#' simClass <- computeSimilarityClass(resLearn)
+#'   simVar <- computeSimilarityVar(resLearn)
+#'   simClass <- computeSimilarityClass(resLearn)
+#' }
 #'
 #' @author Quentin Grimonprez
 #' @seealso \code{\link{heatmapVar}} \code{\link{heatmapClass}}
@@ -353,7 +360,8 @@ reduceRMixtCompOutputIntern <- function(outMixtComp, completed = TRUE, log = TRU
 
     if (log) {
       if (outMixtComp$variable$type[[nomVar]] %in% c(
-        "LatentClass", "Gaussian", "Multinomial", "Poisson", "Weibull", "NegativeBinomial")) {
+        "LatentClass", "Gaussian", "Multinomial", "Poisson", "Weibull", "NegativeBinomial"
+      )) {
         outMixtComp$variable$param[[nomVar]]$log <- NULL
       }
 
